==> kube-integration-1.15.17.tgz: package/lib/helm/release/helm2/release.controller.js <==
'use strict';

const _ = require('lodash');
const Promise = require('bluebird');
const YAML = require('js-yaml');
const Base = require('../../../kube-native/resource.base.controller');
const ReleasePool = require('./pool');
const { parseFamiliarName } = require('@codefresh-io/docker-reference');
const CFError = require('cf-errors');

const TILLER_LABEL='OWNER=TILLER';

class ReleaseController extends Base {

    _getRelevantConfigmaps(name, revisions = []) {
        const basicLabel = TILLER_LABEL;
        const cmCtl = this._kubeManager
            .getConfigmapController(this._ns);
        let labelSelector = name ? `${name},${basicLabel}` : basicLabel;
        if (!revisions || revisions.length === 0) {
            return cmCtl
                .get({
                    labelSelector
                });
        } else {
            return Promise.map(revisions, (revision) => {
                return cmCtl
                    .get({
                        labelSelector: `VERSION=${revision},${labelSelector}`
                    });
            })
                .then(_.flattenDeep)
                .then(_.compact);
        }
    }

    _ensureTillerExistOnNamespace(tillerServiceName = 'tiller-deploy'){
        return this._kubeManager
            .getServiceController(this._ns)
            .describe(tillerServiceName)
            .catch((err) => {
                throw new CFError({
                    message: `Tiller not found in namespace ${this._ns}`,
                    recognized: true
                });
            });
    }

    get() {
        return this._ensureTillerExistOnNamespace()
        .then(() => this._getRelevantConfigmaps())
        .then((configmaps) => {
            const pool = new ReleasePool({ configmaps });
            return pool.prepareReleases()
                .then(() => pool.getAllReleases());
        });
    }

    /**
     *
     * @param actualVersions - it is revision that we need start from for retrieval,
     * it is part of optimization, we not need retrieve revisions if we already have it,
     * { datadog: 1, demochat: 2}
     * @returns {*}
     */
    getWithOptimization(actualVersions = {}) {
        return this._ensureTillerExistOnNamespace()
            .then(() => this._getRelevantConfigmaps())
            .then(async (configmaps) => {
                const pool = new ReleasePool({ configmaps });
                await pool.prepareReleasesWithOptimization(actualVersions);
                const releases = await pool.getAllReleases();
                return { releases, ignoredReleases: pool.getIgnoredRevisions() };
            });
    }

    describe(name, revisions = []) {
        let finalRelease;
        return this._ensureTillerExistOnNamespace()
        .then(() => this._getRelevantConfigmaps(`NAME=${name}`, revisions))
        .then((configmaps) => {
            if(!configmaps || _.isEmpty(configmaps)){
                throw new CFError({
                    message: `Release ${name} not found`,
                    recognized: true
                });
            }
            const pool = new ReleasePool({ configmaps });
            return pool.prepareReleases()
            .then(() => pool.getReleaseFromPool(name))
        });
    }

    create(resourceDescriptor) {
        throw new CFError('Not supported yet');
    }

    delete(name) {
        throw new CFError('Not supported yet');
    }

    update(name, resourceDescriptor) {
        throw new CFError('Not supported yet');
    }

    publishEvent(name, data) {
        this.emit(name, data);
    }

    getTillerVersion(tillerServiceName = 'tiller-deploy') {
        return this._ensureTillerExistOnNamespace(tillerServiceName)
            .then(() => this._kubeManager.getServiceController(this._ns).describe(tillerServiceName))
            .then(service => _.chain(service.getServiceSelector()).map((v, k) => `${k}=${v}`).join(',').value())
            .then(labelSelector => this._kubeManager.getPodController(this._ns).get({
                labelSelector
            }))
            .then((pods) => {
                if(!pods){
                    throw new CFError({
                        message: 'Could not find tiller pod',
                        recognized: true
                    });
                }
                return pods[0].getImages()
            })
            .then(images => {
                const tiller = images.find(image => image.name.includes('tiller'));
                if (!tiller) {
                    throw new CFError({
                        message: 'Could not find tiller container',
                        recognized: true
                    });
                }
                return parseFamiliarName(tiller.name);
            })
            .then(reference => reference.tag);
    }

    compareRevisionsInRelease(releaseName, base, head){
        return this.describe(releaseName, [base, head])
        .then(release => release.compareRevisions(base, head));
    }

    getChartManifestForRevision(name, revision){
        return this.describe(name, revision && [revision])
        .then(release => release.getRevisionByVersion(revision))
        .then(revision => revision.getManifest())
    }

    getChartValuesForRevision(name, revision){
        return this.describe(name, revision && [revision])
        .then(release => release.getRevisionByVersion(revision))
        .then(revision => revision.getValues())
    }
    getChartHooksForRevision(name, revision){
        return this.describe(name, revision && [revision])
        .then(release => release.getRevisionByVersion(revision))
        .then(revision => revision.getHooks())
    }

    getChartDescriptorForRevision(name, revision){
        return this.describe(name, revision && [revision])
        .then(release => release.getRevisionByVersion(revision))
        .then(revision => revision.getChart())
    }

}

module.exports = ReleaseController;

==> kube-integration-1.21.0.tgz: package/lib/helm/release/helm2/release.controller.js <==
'use strict';

const _ = require('lodash');
const Promise = require('bluebird');
const YAML = require('js-yaml');
const Base = require('../../../kube-native/resource.base.controller');
const ReleasePool = require('./pool');
const { parseFamiliarName } = require('@codefresh-io/docker-reference');
const CFError = require('cf-errors');

const TILLER_LABEL='OWNER=TILLER';

class ReleaseController extends Base {

    _getRelevantConfigmaps(name, revisions = []) {
        const basicLabel = TILLER_LABEL;
        const cmCtl = this._kubeManager
            .getConfigmapController(this._ns);
        let labelSelector = name ? `${name},${basicLabel}` : basicLabel;
        if (!revisions || revisions.length === 0) {
            return cmCtl
                .get({
                    labelSelector
                });
        } else {
            return Promise.map(revisions, (revision) => {
                return cmCtl
                    .get({
                        labelSelector: `VERSION=${revision},${labelSelector}`
                    });
            })
                .then(_.flattenDeep)
                .then(_.compact);
        }
    }

    _ensureTillerExistOnNamespace(tillerServiceName = 'tiller-deploy'){
        return this._kubeManager
            .getServiceController(this._ns)
            .describe(tillerServiceName)
            .catch((err) => {
                throw new CFError({
                    message: `Tiller not found in namespace ${this._ns}`,
                    recognized: true
                });
            });
    }

    get() {
        return this._ensureTillerExistOnNamespace()
        .then(() => this._getRelevantConfigmaps())
        .then((configmaps) => {
            const pool = new ReleasePool({ configmaps });
            return pool.prepareReleases()
                .then(() => pool.getAllReleases());
        });
    }

    /**
     *
     * @param actualVersions - it is revision that we need start from for retrieval,
     * it is part of optimization, we not need retrieve revisions if we already have it,
     * { datadog: 1, demochat: 2}
     * @returns {*}
     */
    getWithOptimization(actualVersions = {}) {
        return this._ensureTillerExistOnNamespace()
            .then(() => this._getRelevantConfigmaps())
            .then(async (configmaps) => {
                const pool = new ReleasePool({ configmaps });
                await pool.prepareReleasesWithOptimization(actualVersions);
                const releases = await pool.getAllReleases();
                return { releases, ignoredReleases: pool.getIgnoredRevisions(), deletedReleases: pool.getDeletedReleases(_.keys(actualVersions)) };
            });
    }

    describe(name, revisions = []) {
        let finalRelease;
        return this._ensureTillerExistOnNamespace()
        .then(() => this._getRelevantConfigmaps(`NAME=${name}`, revisions))
        .then((configmaps) => {
            if(!configmaps || _.isEmpty(configmaps)){
                throw new CFError({
                    message: `Release ${name} not found`,
                    recognized: true
                });
            }
            const pool = new ReleasePool({ configmaps });
            return pool.prepareReleases()
            .then(() => pool.getReleaseFromPool(name))
        });
    }

    create(resourceDescriptor) {
        throw new CFError('Not supported yet');
    }

    delete(name) {
        throw new CFError('Not supported yet');
    }

    update(name, resourceDescriptor) {
        throw new CFError('Not supported yet');
    }

    publishEvent(name, data) {
        this.emit(name, data);
    }

    getTillerVersion(tillerServiceName = 'tiller-deploy') {
        return this._ensureTillerExistOnNamespace(tillerServiceName)
            .then(() => this._kubeManager.getServiceController(this._ns).describe(tillerServiceName))
            .then(service => _.chain(service.getServiceSelector()).map((v, k) => `${k}=${v}`).join(',').value())
            .then(labelSelector => this._kubeManager.getPodController(this._ns).get({
                labelSelector
            }))
            .then((pods) => {
                if(!pods){
                    throw new CFError({
                        message: 'Could not find tiller pod',
                        recognized: true
                    });
                }
                return pods[0].getImages()
            })
            .then(images => {
                const tiller = images.find(image => image.name.includes('tiller'));
                if (!tiller) {
                    throw new CFError({
                        message: 'Could not find tiller container',
                        recognized: true
                    });
                }
                return parseFamiliarName(tiller.name);
            })
            .then(reference => reference.tag);
    }

    compareRevisionsInRelease(releaseName, base, head){
        return this.describe(releaseName, [base, head])
        .then(release => release.compareRevisions(base, head));
    }

    getChartManifestForRevision(name, revision){
        return this.describe(name, revision && [revision])
        .then(release => release.getRevisionByVersion(revision))
        .then(revision => revision.getManifest())
    }

    getChartValuesForRevision(name, revision){
        return this.describe(name, revision && [revision])
        .then(release => release.getRevisionByVersion(revision))
        .then(revision => revision.getValues())
    }
    getChartHooksForRevision(name, revision){
        return this.describe(name, revision && [revision])
        .then(release => release.getRevisionByVersion(revision))
        .then(revision => revision.getHooks())
    }

    getChartDescriptorForRevision(name, revision){
        return this.describe(name, revision && [revision])
        .then(release => release.getRevisionByVersion(revision))
        .then(revision => revision.getChart())
    }

}

module.exports = ReleaseController;
